@@ -23,6 +23,9 @@ class BotManager(Client):
     TOKEN_INDEX = 0
     _loop = None
     _scheduler_thread = None
+    font = 0
+    sudo_users = []
+
 
     def create_client(self,token_index):
         super().__init__(
@@ -69,7 +72,7 @@ class BotManager(Client):
         for i in range(len(self.tokens)):
             until = self._flood_data.get(i, 0)
             if until <= now:
-                logger.info(f"Token {i} is not in flood.")
+                logger.info(f"Token 0{i + 1} is not in flood.")
                 self._flood_data.pop(i, None)
                 self.save_flood_data()
                 non_flooded.append((i))
@@ -102,12 +105,14 @@ class BotManager(Client):
         self._web_runner = await self.web_server.setup_web_server(8443)
 
     async def powerup(self):
-        self.font = self.db.Settings.get(key="font",datatype=str)
-        self.sudo_users = self.db.Settings.get(key="sudo_users",datatype=list,default=[])
-        if not self.font:
-            logger.info("Font not set, defaulting to font 1")
-            self.db.Settings.set("font", "1")
-            self.font = 1
+        if hasattr(self, "db"):
+            self.font = self.db.Settings.get(key="font",datatype=str)
+            self.sudo_users = self.db.Settings.get(key="sudo_users",datatype=list,default=[])
+
+            if not self.font:
+                logger.info("Font not set, defaulting to font 1")
+                self.db.Settings.set("font", "1")
+                self.font = 1
 
         self.load_flood_data()
         self.TOKEN_INDEX= self.get_token_index_from_flood_file()
